src/mobility/helper/mobility-helper.h
changeset 9096 94215be61edf
parent 8984 85eed149a0ea
child 11045 6024c150e4c8
--- a/src/mobility/helper/mobility-helper.h	Thu Sep 27 13:29:03 2012 -0400
+++ b/src/mobility/helper/mobility-helper.h	Fri Sep 28 12:22:18 2012 -0700
@@ -24,6 +24,7 @@
 #include <vector>
 #include "ns3/object-factory.h"
 #include "ns3/attribute.h"
+#include "ns3/output-stream-wrapper.h"
 #include "ns3/position-allocator.h"
 #include "node-container.h"
 
@@ -221,31 +222,31 @@
   void InstallAll (void);
 
   /**
    * \param os output stream
    * \param nodeid the id of the node to generate ascii output for.
    *
    * Enable ascii output on the mobility model associated to the
    * specified nodeid and dump that to the specified stdc++ output 
    * stream.
    */
-  static void EnableAscii (std::ostream &os, uint32_t nodeid);
+  static void EnableAscii (Ptr<OutputStreamWrapper> stream, uint32_t nodeid);
   /**
    * \param os output stream
    * \param n node container
    *
    * Enable ascii output on the mobility model associated each of
    * the nodes in the input container and dump that to the 
    * specified stdc++ output stream.
    */
-  static void EnableAscii (std::ostream &os, NodeContainer n);
+  static void EnableAscii (Ptr<OutputStreamWrapper> stream, NodeContainer n);
   /**
    * \param os output stream
    *
    * Enable ascii output on the mobility model associated
    * every node in the system and dump that to the specified 
    * stdc++ output stream.
    */
-  static void EnableAsciiAll (std::ostream &os);
+  static void EnableAsciiAll (Ptr<OutputStreamWrapper> stream);
   /**
    * Assign a fixed random variable stream number to the random variables
    * used by the mobility models (including any position allocators assigned
@@ -264,7 +265,7 @@
   /**
    * \internal
    */
-  static void CourseChanged (std::ostream *os, Ptr<const MobilityModel> mobility);
+  static void CourseChanged (Ptr<OutputStreamWrapper> stream, Ptr<const MobilityModel> mobility);
   std::vector<Ptr<MobilityModel> > m_mobilityStack;
   ObjectFactory m_mobility;
   Ptr<PositionAllocator> m_position;
@@ -221,31 +222,31 @@
 
   /**
-   * \param os output stream
+   * \param stream an output stream wrapper
    * \param nodeid the id of the node to generate ascii output for.
    *
@@ -221,31 +222,31 @@
   /**
-   * \param os output stream
+   * \param stream an output stream wrapper
    * \param n node container
    *
@@ -221,31 +222,31 @@
   /**
-   * \param os output stream
+   * \param stream an output stream wrapper
    *
    * Enable ascii output on the mobility model associated